@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2000-2006 by Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2006/02/28, v3.000.004, package ASNMTAP::Asnmtap::Applications::CGI Object-Oriented Perl
+# 2006/03/18, v3.000.006, package ASNMTAP::Asnmtap::Applications::CGI making Asnmtap v3.000.xxx compatible
 # ----------------------------------------------------------------------------------------------------------
 
 package ASNMTAP::Asnmtap::Applications::CGI;
@@ -19,93 +19,118 @@ use Time::Local;
 
 # include the class files - - - - - - - - - - - - - - - - - - - - - - - -
 
-use lib qw(/opt/asnmtap/.);
-use ASNMTAP::Asnmtap::Applications v3.000.004;
-use ASNMTAP::Asnmtap::Applications qw(:DEFAULT :ASNMTAP :CGI);
+use ASNMTAP::Time qw(&get_datetimeSignal);
+
+use ASNMTAP::Asnmtap::Applications qw(:APPLICATIONS :COMMANDS :_HIDDEN :CGI);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use Exporter;
+BEGIN {
+  use Exporter ();
 
-our @ISA         = qw(Exporter ASNMTAP::Asnmtap::Applications);
+  @ASNMTAP::Asnmtap::Applications::CGI::ISA         = qw(Exporter ASNMTAP::Asnmtap::Applications);
 
-our @EXPORT      = qw($APPLICATION $BUSINESS $DEPARTMENT $COPYRIGHT $SENDEMAILTO);
+  %ASNMTAP::Asnmtap::Applications::CGI::EXPORT_TAGS = (ALL         => [ qw($APPLICATION $BUSINESS $DEPARTMENT $COPYRIGHT $SENDEMAILTO
+                                                                           $CAPTUREOUTPUT
+                                                                           $PREFIXPATH $LOGPATH $PIDPATH
+                                                                           %ERRORS %STATE %TYPE
 
-our @EXPORT_OK   = qw($CAPTUREOUTPUT $PREFIXPATH $PLUGINPATH $PERLCOMMAND $RSYNCCOMMAND $SCPCOMMAND $SSHCOMMAND %ERRORS %STATE &get_datetimeSignal &scan_socket_info &sending_mail
-                      $APPLICATIONPATH
+                                                                           &call_system &sending_mail
 
-                      $ASNMTAPMANUAL
-                      $DATABASE
-                      $CONFIGDIR $DEBUGDIR $REPORTDIR $RESULTSDIR
-                      $CGISESSPATH $HTTPSPATH $IMAGESPATH $PDPHELPPATH $RESULTSPATH $LOGPATH $PIDPATH $SSHKEYPATH $WWWKEYPATH
-                      $HTTPSSERVER $REMOTE_HOST $REMOTE_ADDR $HTTPSURL $IMAGESURL $PDPHELPURL $RESULTSURL
-                      $SERVERSMTP $SMTPUNIXSYSTEM $SERVERLISTSMTP $SENDMAILFROM
-                      $SSHLOGONNAME $RSYNCIDENTITY $SSHIDENTITY $WWWIDENTITY
-                      $RMVERSION $RMDEFAULTUSER
-                      $HTMLTOPDFPRG $HTMLTOPDFHOW $HTMLTOPDFOPTNS
-                      $RECORDSONPAGE $NUMBEROFFTESTS $VERIFYNUMBEROK $VERIFYMINUTEOK $FIRSTSTARTDATE $STRICTDATE
-                      %COLORS %COLORSPIE %COLORSRRD %COLORSTABLE %ICONS %ICONSACK %ICONSRECORD %ICONSSYSTEM %SOUND %QUARTERS
-                      &get_session_param
-                      &set_doIt_and_doOffline
-                      &encode_html_entities &print_header &print_legend
+                                                                           $CHATCOMMAND $KILLALLCOMMAND $PERLCOMMAND $PPPDCOMMAND $ROUTECOMMAND $RSYNCCOMMAND $SCPCOMMAND $SSHCOMMAND
 
-                      $SERVERNAMEREADWRITE $SERVERPORTREADWRITE $SERVERUSERREADWRITE $SERVERPASSREADWRITE
-                      $SERVERNAMEREADONLY $SERVERPORTREADONLY $SERVERUSERREADONLY $SERVERPASSREADONLY
-                      $SERVERTABLCLLCTRDMNS $SERVERTABLCOMMENTS $SERVERTABLCOUNTRIES $SERVERTABLCRONTABS $SERVERTABLDSPLYDMNS $SERVERTABLDSPLYGRPS $SERVERTABLEVENTS $SERVERTABLHOLIDYS $SERVERTABLHLDSBNDL $SERVERTABLLANGUAGE $SERVERTABLPAGEDIRS $SERVERTABLPLUGINS $SERVERTABLREPORTS $SERVERTABLRSLTSDR $SERVERTABLSERVERS $SERVERTABLUSERS $SERVERTABLVIEWS
+                                                                           &_checkAccObjRef
+                                                                           &_checkSubArgs0 &_checkSubArgs1 &_checkSubArgs2
+                                                                           &_checkReadOnly0 &_checkReadOnly1 &_checkReadOnly2
+                                                                           &_dumpValue
+
+                                                                           $APPLICATIONPATH $PLUGINPATH
+																		   
+                                                                           $ASNMTAPMANUAL
+                                                                           $DATABASE
+                                                                           $CONFIGDIR $CGISESSDIR $DEBUGDIR $REPORTDIR $RESULTSDIR
+                                                                           $CGISESSPATH $HTTPSPATH $IMAGESPATH $PDPHELPPATH $RESULTSPATH $LOGPATH $PIDPATH $SSHKEYPATH $WWWKEYPATH
+                                                                           $HTTPSSERVER $REMOTE_HOST $REMOTE_ADDR $HTTPSURL $IMAGESURL $PDPHELPURL $RESULTSURL
+                                                                           $SERVERSMTP $SMTPUNIXSYSTEM $SERVERLISTSMTP $SENDMAILFROM
+                                                                           $SSHLOGONNAME $RSYNCIDENTITY $SSHIDENTITY $WWWIDENTITY
+                                                                           $RMVERSION $RMDEFAULTUSER
+                                                                           $HTMLTOPDFPRG $HTMLTOPDFHOW $HTMLTOPDFOPTNS
+                                                                           $RECORDSONPAGE $NUMBEROFFTESTS $VERIFYNUMBEROK $VERIFYMINUTEOK $FIRSTSTARTDATE $STRICTDATE
+                                                                           %COLORS %COLORSPIE %COLORSRRD %COLORSTABLE %ICONS %ICONSACK %ICONSRECORD %ICONSSYSTEM %SOUND %QUARTERS
+                                                                           &get_session_param
+                                                                           &set_doIt_and_doOffline
+                                                                           &encode_html_entities &print_header &print_legend
+
+                                                                           $SERVERNAMEREADWRITE $SERVERPORTREADWRITE $SERVERUSERREADWRITE $SERVERPASSREADWRITE
+                                                                           $SERVERNAMEREADONLY $SERVERPORTREADONLY $SERVERUSERREADONLY $SERVERPASSREADONLY
+                                                                           $SERVERTABLCLLCTRDMNS $SERVERTABLCOMMENTS $SERVERTABLCOUNTRIES $SERVERTABLCRONTABS $SERVERTABLDSPLYDMNS $SERVERTABLDSPLYGRPS $SERVERTABLEVENTS $SERVERTABLHOLIDYS $SERVERTABLHLDSBNDL $SERVERTABLLANGUAGE $SERVERTABLPAGEDIRS $SERVERTABLPLUGINS $SERVERTABLREPORTS $SERVERTABLRSLTSDR $SERVERTABLSERVERS $SERVERTABLUSERS $SERVERTABLVIEWS
 					  
-                      &user_session_and_access_control
-                      &do_action_DBI &error_trap_DBI &check_record_exist &create_sql_query_events_from_range_year_month
-                      &get_title &get_sql_startDate_sqlEndDate_numberOfDays_test &get_sql_crontab_scheduling_report_data
-                      &create_combobox_from_keys_and_values_pairs &create_combobox_from_DBI &create_combobox_multiple_from_DBI 
-                      &record_navigation_table &record_navigation_bar);
+                                                                           &user_session_and_access_control
+                                                                           &do_action_DBI &error_trap_DBI &check_record_exist &create_sql_query_events_from_range_year_month
+                                                                           &get_title &get_sql_startDate_sqlEndDate_numberOfDays_test &get_sql_crontab_scheduling_report_data
+                                                                           &create_combobox_from_keys_and_values_pairs &create_combobox_from_DBI &create_combobox_multiple_from_DBI 
+                                                                           &record_navigation_table &record_navigation_bar) ],
 
-our %EXPORT_TAGS = (ASNMTAP     => [qw($CAPTUREOUTPUT $PREFIXPATH $PLUGINPATH $PERLCOMMAND $RSYNCCOMMAND $SCPCOMMAND $SSHCOMMAND %ERRORS %STATE &get_datetimeSignal &scan_socket_info &sending_mail)],
+                                                      APPLICATIONS => [ qw($APPLICATION $BUSINESS $DEPARTMENT $COPYRIGHT $SENDEMAILTO
+                                                                           $CAPTUREOUTPUT
+                                                                           $PREFIXPATH $PLUGINPATH $LOGPATH $PIDPATH
+                                                                           %ERRORS %STATE %TYPE
 
-                    CGI         => [qw($APPLICATIONPATH
+                                                                           &sending_mail) ],
 
-                                       $DATABASE
-                                       $CONFIGDIR $DEBUGDIR $REPORTDIR $RESULTSDIR
-                                       $CGISESSPATH $HTTPSPATH $IMAGESPATH $PDPHELPPATH $RESULTSPATH $LOGPATH $PIDPATH $SSHKEYPATH $WWWKEYPATH
-                                       $HTTPSSERVER $REMOTE_HOST $REMOTE_ADDR $HTTPSURL $IMAGESURL $PDPHELPURL $RESULTSURL
-                                       $SERVERSMTP $SMTPUNIXSYSTEM $SERVERLISTSMTP $SENDMAILFROM
-                                       $HTMLTOPDFPRG $HTMLTOPDFHOW $HTMLTOPDFOPTNS
-                                       $RECORDSONPAGE $NUMBEROFFTESTS $VERIFYNUMBEROK $VERIFYMINUTEOK $FIRSTSTARTDATE $STRICTDATE
-                                       &encode_html_entities &print_header &print_legend
+                                                      COMMANDS     => [ qw($CHATCOMMAND $KILLALLCOMMAND $PERLCOMMAND $PPPDCOMMAND $ROUTECOMMAND $RSYNCCOMMAND $SCPCOMMAND $SSHCOMMAND) ],
 
-                                       &user_session_and_access_control
-							           &do_action_DBI &error_trap_DBI &check_record_exist
-                                       &get_title
-                                       &create_combobox_from_keys_and_values_pairs &create_combobox_from_DBI &create_combobox_multiple_from_DBI
-                                       &record_navigation_table &record_navigation_bar)],
+                                                     _HIDDEN       => [ qw(&_checkAccObjRef
+                                                                           &_checkSubArgs0 &_checkSubArgs1 &_checkSubArgs2
+                                                                           &_checkReadOnly0 &_checkReadOnly1 &_checkReadOnly2
+                                                                           &_dumpValue) ],
+
+                                                      CGI          => [ qw($APPLICATIONPATH
+
+                                                                           $DATABASE
+                                                                           $CONFIGDIR $CGISESSDIR $DEBUGDIR $REPORTDIR $RESULTSDIR
+                                                                           $CGISESSPATH $HTTPSPATH $IMAGESPATH $PDPHELPPATH $RESULTSPATH $LOGPATH $PIDPATH $SSHKEYPATH $WWWKEYPATH
+                                                                           $HTTPSSERVER $REMOTE_HOST $REMOTE_ADDR $HTTPSURL $IMAGESURL $PDPHELPURL $RESULTSURL
+                                                                           $SERVERSMTP $SMTPUNIXSYSTEM $SERVERLISTSMTP $SENDMAILFROM
+                                                                           $HTMLTOPDFPRG $HTMLTOPDFHOW $HTMLTOPDFOPTNS
+                                                                           $RECORDSONPAGE $NUMBEROFFTESTS $VERIFYNUMBEROK $VERIFYMINUTEOK $FIRSTSTARTDATE $STRICTDATE
+                                                                           &encode_html_entities &print_header &print_legend
+
+                                                                           &user_session_and_access_control
+                                    	 	 					           &do_action_DBI &error_trap_DBI &check_record_exist
+                                                                           &get_title
+                                                                           &create_combobox_from_keys_and_values_pairs &create_combobox_from_DBI &create_combobox_multiple_from_DBI
+                                                                           &record_navigation_table &record_navigation_bar ) ],
 
 
-                    MEMBER      => [qw(%COLORS %COLORSTABLE %ICONS %ICONSRECORD)],
+                                                      MEMBER       => [ qw(%COLORS %COLORSTABLE %ICONS %ICONSRECORD ) ],
 
-                    MODERATOR   => [qw(%COLORS %COLORSTABLE %ICONS %ICONSRECORD %ICONSSYSTEM
-                                       $SSHLOGONNAME
-                                       &get_session_param
-                                       &set_doIt_and_doOffline
+                                                      MODERATOR    => [ qw(%COLORS %COLORSTABLE %ICONS %ICONSRECORD %ICONSSYSTEM
+                                                                           $SSHLOGONNAME
+                                                                           &get_session_param
+                                                                           &set_doIt_and_doOffline
 
-                                       &get_sql_crontab_scheduling_report_data)],
+                                                                           &get_sql_crontab_scheduling_report_data ) ],
 
-                    ADMIN       => [qw(%COLORSTABLE %ICONSRECORD)],
+                                                      ADMIN        => [ qw(%COLORSTABLE %ICONSRECORD ) ],
 
-                    SADMIN      => [qw(%COLORSTABLE %ICONSRECORD
-                                       $SSHLOGONNAME $RSYNCIDENTITY $SSHIDENTITY $WWWIDENTITY
-                                       $RMVERSION $RMDEFAULTUSER
-                                       &get_csvfiledate &get_csvfiletime)],
+                                                      SADMIN       => [ qw(%COLORSTABLE %ICONSRECORD
+                                                                           $SSHLOGONNAME $RSYNCIDENTITY $SSHIDENTITY $WWWIDENTITY
+                                                                           $RMVERSION $RMDEFAULTUSER ) ],
 
-                    DBREADONLY  => [qw($SERVERNAMEREADONLY $SERVERPORTREADONLY $SERVERUSERREADONLY $SERVERPASSREADONLY)],
-                    DBREADWRITE => [qw($SERVERNAMEREADWRITE $SERVERPORTREADWRITE $SERVERUSERREADWRITE $SERVERPASSREADWRITE)],
-                    DBTABLES    => [qw($SERVERTABLCLLCTRDMNS $SERVERTABLCOMMENTS $SERVERTABLCOUNTRIES $SERVERTABLCRONTABS $SERVERTABLDSPLYDMNS $SERVERTABLDSPLYGRPS $SERVERTABLEVENTS $SERVERTABLHOLIDYS $SERVERTABLHLDSBNDL $SERVERTABLLANGUAGE $SERVERTABLPAGEDIRS $SERVERTABLPLUGINS $SERVERTABLREPORTS $SERVERTABLRSLTSDR $SERVERTABLSERVERS $SERVERTABLUSERS $SERVERTABLVIEWS)],
+                                                      DBREADONLY   => [ qw($SERVERNAMEREADONLY $SERVERPORTREADONLY $SERVERUSERREADONLY $SERVERPASSREADONLY ) ],
+                                                      DBREADWRITE  => [ qw($SERVERNAMEREADWRITE $SERVERPORTREADWRITE $SERVERUSERREADWRITE $SERVERPASSREADWRITE ) ],
+                                                      DBTABLES     => [ qw($SERVERTABLCLLCTRDMNS $SERVERTABLCOMMENTS $SERVERTABLCOUNTRIES $SERVERTABLCRONTABS $SERVERTABLDSPLYDMNS $SERVERTABLDSPLYGRPS $SERVERTABLEVENTS $SERVERTABLHOLIDYS $SERVERTABLHLDSBNDL $SERVERTABLLANGUAGE $SERVERTABLPAGEDIRS $SERVERTABLPLUGINS $SERVERTABLREPORTS $SERVERTABLRSLTSDR $SERVERTABLSERVERS $SERVERTABLUSERS $SERVERTABLVIEWS ) ],
 
+                                                      REPORTS      => [ qw(%COLORS %COLORSPIE %COLORSRRD %COLORSTABLE %ICONS %QUARTERS
 
-                    REPORTS     => [qw(%COLORS %COLORSPIE %COLORSRRD %COLORSTABLE %ICONS %QUARTERS
+                                                                           &create_sql_query_events_from_range_year_month
+                                                                           &get_sql_startDate_sqlEndDate_numberOfDays_test) ] );
 
-                                       &create_sql_query_events_from_range_year_month
-                                       &get_sql_startDate_sqlEndDate_numberOfDays_test)]);
+  @ASNMTAP::Asnmtap::Applications::CGI::EXPORT_OK   = ( @{ $ASNMTAP::Asnmtap::Applications::CGI::EXPORT_TAGS{ALL} } );
 
-our $VERSION     = 3.000.004;
+  $ASNMTAP::Asnmtap::Applications::CGI::VERSION     = 3.000.006;
+}
 
 # = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
 # Public subs = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
@@ -151,7 +176,7 @@ sub user_session_and_access_control {
   my ($errorUserAccessControl, $sessionID, $userType, $cfhOld, $cfhNew, $password);
   $sessionID = "";
 
-  if (! $sessionControl or ($ENV{'REMOTE_ADDR'} eq $REMOTE_ADDR)) {
+  if (! $sessionControl or ($ENV{REMOTE_ADDR} eq $REMOTE_ADDR)) {
     ($cfhOld) = $|; $cfhNew = select (STDOUT); $| = 1;
     print $cgi->header;
     $| = $cfhOld; select ($cfhNew);
@@ -168,9 +193,9 @@ sub user_session_and_access_control {
 
     if ( $logonRequestLogoff ne 'logoff' ) {
       if ( $session->param('~logged-in') ) {
-        $subTitle .= "&nbsp;&nbsp;<a href=\"" .$ENV{"SCRIPT_NAME"}. "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;logonRequest=logoff\"><IMG SRC=\"$IMAGESURL/logoff.jpg\" title=\"Logoff " .$session->param('remoteUser'). "\" alt=\"Logoff " .$session->param('remoteUser'). "\" BORDER=0></a>";
+        $subTitle .= "&nbsp;&nbsp;<a href=\"" .$ENV{SCRIPT_NAME}. "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;logonRequest=logoff\"><IMG SRC=\"$IMAGESURL/logoff.jpg\" title=\"Logoff " .$session->param('remoteUser'). "\" alt=\"Logoff " .$session->param('remoteUser'). "\" BORDER=0></a>";
       } else {
-        $session->param('remoteUser', $ENV{'REMOTE_USER'}) if ($ENV{'REMOTE_USER'});
+        $session->param('remoteUser', $ENV{REMOTE_USER}) if ($ENV{REMOTE_USER});
       }
     } else {
       if ( $debug eq 'T' and defined $queryString ) {
@@ -219,9 +244,9 @@ sub user_session_and_access_control {
     } elsif ($level eq 'moderator') {           # Moderator
       $accessGranted = 1 if ($TuserType >= 2);
     } elsif ($level eq 'member') {              # Member
-      $accessGranted = 1 if ($TuserType >= 1 and $pagedir ne "<NIHIL>" and ($Tpagedir =~ /\/$pagedir\//));
+      $accessGranted = 1 if ($TuserType >= 1 and $pagedir ne '<NIHIL>' and ($Tpagedir =~ /\/$pagedir\//));
     } else {                                    # Guest
-      $accessGranted = 1 if ($pagedir ne "<NIHIL>" and ($Tpagedir =~ /\/$pagedir\//));
+      $accessGranted = 1 if ($pagedir ne '<NIHIL>' and ($Tpagedir =~ /\/$pagedir\//));
     }
 
     $subTitle = setAccessControlParameters( $level, $pagedir, $pageset, $debug, $cgi, $session, $sessionID, $subTitle, $queryString );
@@ -315,7 +340,7 @@ sub user_session_and_access_control {
         if (defined $errorUserAccessControl) {
           $errorUserAccessControl .= "<br>Please contact us with the details of your action.";
 
-          if (! $rv) {
+          unless ( $rv ) {
             print "<br>\n<table WIDTH=\"100%\" border=0><tr><td class=\"HelpPluginFilename\">\n<font size=\"+1\">$errorUserAccessControl</font>\n</td></tr></table>\n<br>\n";
             return ("", 0, 0, 0, 0, 1, 1, $errorUserAccessControl, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $subTitle);
           }
@@ -324,19 +349,19 @@ sub user_session_and_access_control {
         } elsif( $logonTimestamp > $currentTime or $logonTimestamp < ($currentTime - 300) ) {
           $errorUserAccessControl = "Time stamp invalid";
         } else {
-          if ( $ENV{'REMOTE_ADDR'} ) {
+          if ( $ENV{REMOTE_ADDR} ) {
             if ( $CremoteAddr ne "" ) {
               use NetAddr::IP;
               my $netmask = (int($CremoteNetmask) or 32);
-              my $ipAddr  = NetAddr::IP->new($ENV{'REMOTE_ADDR'});
+              my $ipAddr  = NetAddr::IP->new($ENV{REMOTE_ADDR});
               my $ipRange = NetAddr::IP->new("$CremoteAddr/$netmask");
-              $errorUserAccessControl = "IP Address Forbidden." if (! $ipRange->contains($ipAddr));
+              $errorUserAccessControl = "IP Address Forbidden." unless ( $ipRange->contains ( $ipAddr ) );
             }
           }
 
           $errorUserAccessControl = "You don't have enough permissions!" if ( $userType > int($CuserType) );
 
-		  if (! defined $errorUserAccessControl) {
+		  unless ( defined $errorUserAccessControl ) {
             my $accessGranted = 0;
 
             if ($level eq 'sadmin') {                   # Server Administrator
@@ -346,14 +371,14 @@ sub user_session_and_access_control {
             } elsif ($level eq 'moderator') {           # Moderator
               $accessGranted = 1 if ($CuserType >= 2);
             } elsif ($level eq 'member') {              # Member
-              $accessGranted = 1 if ($CuserType >= 1 and $pagedir ne "<NIHIL>" and ($Cpagedir =~ /\/$pagedir\//));
+              $accessGranted = 1 if ($CuserType >= 1 and $pagedir ne '<NIHIL>' and ($Cpagedir =~ /\/$pagedir\//));
             } else {                                    # Guest
-              $accessGranted = 1 if ($pagedir ne "<NIHIL>" and ($Cpagedir =~ /\/$pagedir\//));
+              $accessGranted = 1 if ($pagedir ne '<NIHIL>' and ($Cpagedir =~ /\/$pagedir\//));
             }
 
-            $errorUserAccessControl = "You are onto the wrong place to be!" if ( ! $accessGranted );
+            $errorUserAccessControl = "You are onto the wrong place to be!" unless ( $accessGranted );
 
-  		    if (! defined $errorUserAccessControl) {
+  		    unless ( defined $errorUserAccessControl ) {
               $session->param('~logged-in',   1);
               $session->clear(['~login-trials']);
 
@@ -447,7 +472,7 @@ function validateForm() {
 }
 </script>
 <br>
-<form action="$ENV{"SCRIPT_NAME"}" method="post" name="usac" onSubmit="return validateForm();">
+<form action="$ENV{SCRIPT_NAME}" method="post" name="usac" onSubmit="return validateForm();">
   <input type="hidden" name="pagedir"        value="$pagedir">
   <input type="hidden" name="pageset"        value="$pageset">
   <input type="hidden" name="debug"          value="$debug">
@@ -507,7 +532,8 @@ sub error_trap_DBI {
 
   my $subject = "$htmlTitle / error_trap_DBI: " . get_datetimeSignal();
   my $message = get_datetimeSignal() . "\npagedir   : $pagedir\npageset   : $pageset\nhtml title: $htmlTitle\n\nerror message:\n$error_message\n\n--> ERROR: $DBI::err ($DBI::errstr)\n";
-  my ($returnCode) = sending_mail ( $SERVERLISTSMTP, $SENDEMAILTO, $SENDMAILFROM, $subject, $message, $debug );
+  my $returnCode = sending_mail ( $SERVERLISTSMTP, $SENDEMAILTO, $SENDMAILFROM, $subject, $message, $debug );
+  print "Problem sending email to the '$APPLICATION' server administrators\n" unless ( $returnCode );
 
   if ( $refresh == 0 ) {
     return (0, $error_message, "DBI Error: $DBI::err", "DBI String: $DBI::errstr");
@@ -632,12 +658,12 @@ sub get_sql_crontab_scheduling_report_data {
     if ( $sth->rows ) {
       while( $sth->fetch() ) {
         if (exists $$uKeys{$uKey}) {
-          $$uKeys{$uKey}->{'collectorDaemon'} .= '|' .$collectorDaemon if ($collectorDaemon ne $$uKeys{$uKey}->{'collectorDaemon'});
-          $$uKeys{$uKey}->{'noOffline'}       .= '|' .$noOffline if ($noOffline ne $$uKeys{$uKey}->{'noOffline'});
+          $$uKeys{$uKey}->{collectorDaemon} .= '|' .$collectorDaemon if ($collectorDaemon ne $$uKeys{$uKey}->{collectorDaemon});
+          $$uKeys{$uKey}->{noOffline}       .= '|' .$noOffline if ($noOffline ne $$uKeys{$uKey}->{noOffline});
         } else {
-          $$uKeys{$uKey}->{'collectorDaemon'}  = $collectorDaemon;
-          $$uKeys{$uKey}->{'noOffline'}        = $noOffline;
-          $$uKeys{$uKey}->{'numberOfLabel'}    = $numberOfLabels;
+          $$uKeys{$uKey}->{collectorDaemon}  = $collectorDaemon;
+          $$uKeys{$uKey}->{noOffline}        = $noOffline;
+          $$uKeys{$uKey}->{numberOfLabel}    = $numberOfLabels;
 
           if (defined $$uKeysSqlWhere) { $$uKeysSqlWhere .= (($$uKeysSqlWhere) ? ' OR ' : '') . "$SERVERTABLEVENTS.uKey = '$uKey'"; }
 
@@ -651,7 +677,7 @@ sub get_sql_crontab_scheduling_report_data {
           $numberOfLabels++;
         }
 
-        $$uKeys{$uKey}->{'lineNumbers'}->{$lineNumber} = { minute => $minute, hour => $hour, dayOfTheMonth => $dayOfTheMonth, monthOfTheYear => $monthOfTheYear, dayOfTheWeek => $dayOfTheWeek };
+        $$uKeys{$uKey}->{lineNumbers}->{$lineNumber} = { minute => $minute, hour => $hour, dayOfTheMonth => $dayOfTheMonth, monthOfTheYear => $monthOfTheYear, dayOfTheWeek => $dayOfTheWeek };
       }
     } else {
       $hight = $hightMin; $rv = 0; $errorMessage = "There are no Crontabs available";
@@ -712,7 +738,7 @@ sub get_sql_startDate_sqlEndDate_numberOfDays_test {
   $toMonth   = 0 if (! defined $toMonth or $toMonth !~ /^[0-9]+$/);
   $toDay     = 0 if (! defined $toDay or $toDay !~ /^[0-9]+$/);
 
-  return (0, undef, undef, undef) if (! (check_date($fromYear, $fromMonth, $fromDay) and check_date($toYear, $toMonth, $toDay)));
+  return (0, undef, undef, undef) unless ( check_date ( $fromYear, $fromMonth, $fromDay) and check_date($toYear, $toMonth, $toDay ) );
 
   my $switchDate = Delta_Days($fromYear, $fromMonth, $fromDay, $toYear, $toMonth, $toDay);
 
@@ -955,11 +981,11 @@ sub record_navigation_table {
 
     my $actionPressend = ($iconAdd or $iconDelete or $iconDetails or $iconEdit) ? 1 : 0;
     my $actionHeader = ($actionPressend) ? "<th>Action</th>" : "";
-    my $urlWithAccessParameters = $ENV{"SCRIPT_NAME"} . "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;pageNo=1&amp;pageOffset=0$addAccessParameters";
+    my $urlWithAccessParameters = $ENV{SCRIPT_NAME} . "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;pageNo=1&amp;pageOffset=0$addAccessParameters";
 
-    $matchingRecords = "\n      <table align=\"center\" border=0 cellpadding=1 cellspacing=1 bgcolor='$COLORSTABLE{'TABLE'}'>\n	        <tr>$header$actionHeader</tr>\n";
-    $urlWithAccessParameters = $ENV{"SCRIPT_NAME"} . "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;pageNo=$pageNo&amp;pageOffset=$pageOffset";
-    my $numFields = $sth->{'NUM_OF_FIELDS'}; my $colspan = $numFields + 1;
+    $matchingRecords = "\n      <table align=\"center\" border=0 cellpadding=1 cellspacing=1 bgcolor='$COLORSTABLE{TABLE}'>\n	        <tr>$header$actionHeader</tr>\n";
+    $urlWithAccessParameters = $ENV{SCRIPT_NAME} . "?pagedir=$pagedir&amp;pageset=$pageset&amp;debug=$debug&amp;CGISESSID=$sessionID&amp;pageNo=$pageNo&amp;pageOffset=$pageOffset";
+    my $numFields = $sth->{NUM_OF_FIELDS}; my $colspan = $numFields + 1;
 
     if ( $sth->rows ) {
       while ( my $ref = $sth->fetchrow_arrayref ) {
@@ -973,13 +999,13 @@ sub record_navigation_table {
         }
 
         my $urlWithAccessParametersAction = "$urlWithAccessParameters$actionKeys&amp;orderBy=$orderBy&amp;action";
-        $actionItem .= "<a href=\"$urlWithAccessParametersAction=displayView\"><img src=\"$IMAGESURL/$ICONSRECORD{'details'}\" title=\"Display $label\" alt=\"Display $label\" border=\"0\"></a>&nbsp;" if ($iconDetails);
-        $actionItem .= "<a href=\"$urlWithAccessParametersAction=editView\"><img src=\"$IMAGESURL/$ICONSRECORD{'edit'}\" title=\"Edit $label\" alt=\"Edit $label\" border=\"0\"></a>&nbsp;" if ($iconEdit);
-        $actionItem .= "<a href=\"$urlWithAccessParametersAction=duplicateView\"><img src=\"$IMAGESURL/$ICONSRECORD{'duplicate'}\" title=\"Duplicate $label\" alt=\"Duplicate $label\" border=\"0\"></a>&nbsp;" if ($iconAdd);
-        $actionItem .= "<a href=\"$urlWithAccessParametersAction=deleteView\"><img src=\"$IMAGESURL/$ICONSRECORD{'delete'}\" title=\"Delete $label\" alt=\"Delete $label\" border=\"0\"></a>&nbsp;" if ($iconDelete);
+        $actionItem .= "<a href=\"$urlWithAccessParametersAction=displayView\"><img src=\"$IMAGESURL/$ICONSRECORD{details}\" title=\"Display $label\" alt=\"Display $label\" border=\"0\"></a>&nbsp;" if ($iconDetails);
+        $actionItem .= "<a href=\"$urlWithAccessParametersAction=editView\"><img src=\"$IMAGESURL/$ICONSRECORD{edit}\" title=\"Edit $label\" alt=\"Edit $label\" border=\"0\"></a>&nbsp;" if ($iconEdit);
+        $actionItem .= "<a href=\"$urlWithAccessParametersAction=duplicateView\"><img src=\"$IMAGESURL/$ICONSRECORD{duplicate}\" title=\"Duplicate $label\" alt=\"Duplicate $label\" border=\"0\"></a>&nbsp;" if ($iconAdd);
+        $actionItem .= "<a href=\"$urlWithAccessParametersAction=deleteView\"><img src=\"$IMAGESURL/$ICONSRECORD{delete}\" title=\"Delete $label\" alt=\"Delete $label\" border=\"0\"></a>&nbsp;" if ($iconDelete);
         $actionItem .= "</td>" if ($actionPressend);
 
-        $matchingRecords .= "        <tr bgcolor=\"$COLORSTABLE{'STARTBLOCK'}\">";
+        $matchingRecords .= "        <tr bgcolor=\"$COLORSTABLE{STARTBLOCK}\">";
 
         for (my $i = 0;  $i < $numFields;  $i++) {
           my $value;
@@ -1026,13 +1052,13 @@ sub record_navigation_bar {
     my $numberOffRecords  = (($wantedRecordLast - 1) % $showRecordsOnPage) + 1;
     my $numberOffPagesMax = int((($numberRecordsIntoQuery - 1) / $showRecordsOnPage) + 1);
 
-    $navigationBar = "<table border=\"0\" width=\"100%\" bgcolor=\"$COLORSTABLE{'ENDBLOCK'}\"><tr bgcolor=\"$COLORSTABLE{'STARTBLOCK'}\"><td align=\"center\" width=\"36\">$currentPageNo/$numberOffPagesMax</td><td align=\"center\">";
+    $navigationBar = "<table border=\"0\" width=\"100%\" bgcolor=\"$COLORSTABLE{ENDBLOCK}\"><tr bgcolor=\"$COLORSTABLE{STARTBLOCK}\"><td align=\"center\" width=\"36\">$currentPageNo/$numberOffPagesMax</td><td align=\"center\">";
 
     if ($wantedRecordLast > 1) {
       if ($currentPageNo > 1) {
         my $previousPage = $currentPageNo - 1;
         my $previousPageOffset = ($showRecordsOnPage * ($previousPage - 1));
-        $navigationBar .= "&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=1&amp;pageOffset=0\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{'first'}\" ALT=\"First\" BORDER=0></a>&nbsp;<a href=\"$urlWithAccessParameters&pageNo=$previousPage&pageOffset=$previousPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{'left'}\" ALT=\"Left\" BORDER=0></a>&nbsp;&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=1&amp;pageOffset=0\">1</a>";
+        $navigationBar .= "&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=1&amp;pageOffset=0\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{first}\" ALT=\"First\" BORDER=0></a>&nbsp;<a href=\"$urlWithAccessParameters&pageNo=$previousPage&pageOffset=$previousPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{left}\" ALT=\"Left\" BORDER=0></a>&nbsp;&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=1&amp;pageOffset=0\">1</a>";
       } else {
         $navigationBar .= "&nbsp;1";
       }
@@ -1050,7 +1076,7 @@ sub record_navigation_bar {
         my $nextPage = $currentPageNo + 1;
         my $nextPageOffset = ($showRecordsOnPage * ($nextPage - 1));
         my $lastPageOffset = ($showRecordsOnPage * ($numberOffPagesMax - 1));
-        $navigationBar .= "&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=$numberOffPagesMax&amp;pageOffset=$lastPageOffset\">$numberOffPagesMax</a>&nbsp;&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=$nextPage&amp;pageOffset=$nextPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{'right'}\" ALT=\"Right\" BORDER=0></a> <a href=\"$urlWithAccessParameters&amp;pageNo=$numberOffPagesMax&amp;pageOffset=$lastPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{'last'}\" ALT=\"Last\" BORDER=0></a>";
+        $navigationBar .= "&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=$numberOffPagesMax&amp;pageOffset=$lastPageOffset\">$numberOffPagesMax</a>&nbsp;&nbsp;<a href=\"$urlWithAccessParameters&amp;pageNo=$nextPage&amp;pageOffset=$nextPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{right}\" ALT=\"Right\" BORDER=0></a> <a href=\"$urlWithAccessParameters&amp;pageNo=$numberOffPagesMax&amp;pageOffset=$lastPageOffset\"><IMG SRC=\"$IMAGESURL/$ICONSRECORD{last}\" ALT=\"Last\" BORDER=0></a>";
       } else {
         $navigationBar .= "&nbsp;$numberOffPagesMax";
       }
@@ -1074,11 +1100,11 @@ __END__
 
 =head1 NAME
 
-ASNMTAP::Asnmtap::Applications::CGI Subclass of ASNMTAP::Asnmtap::Applications
+ASNMTAP::Asnmtap::Applications::CGI is a Perl module that provides a nice object oriented interface for ASNMTAP CGI Applications
 
 =head1 Description
 
-ASNMTAP::Asnmtap::Applications::CGI is a Perl module that provides a nice object oriented interface for ASNMTAP CGI Applications
+ASNMTAP::Asnmtap::Applications::CGI Subclass of ASNMTAP::Asnmtap::Applications
 
 =head1 SEE ALSO
 
@@ -1095,14 +1121,14 @@ Alex Peeters [alex.peeters@citap.be]
 
 ASNMTAP is based on 'Process System daemons v1.60.17-01', Alex Peeters [alex.peeters@citap.com]
 
-Purpose: CronTab (CT, sysdCT),
-         Disk Filesystem monitoring (DF, sysdDF),
-         Intrusion Detection for FW-1 (ID, sysdID)
-         Process System daemons (PS, sysdPS),
-         Reachability of Remote Hosts on a network (RH, sysdRH),
-         Rotate Logfiles (system activity files) (RL),
-         Remote Socket monitoring (RS, sysdRS),
-         System Activity monitoring (SA, sysdSA).
+ Purpose: CronTab (CT, sysdCT),
+          Disk Filesystem monitoring (DF, sysdDF),
+          Intrusion Detection for FW-1 (ID, sysdID)
+          Process System daemons (PS, sysdPS),
+          Reachability of Remote Hosts on a network (RH, sysdRH),
+          Rotate Logfiles (system activity files) (RL),
+          Remote Socket monitoring (RS, sysdRS),
+          System Activity monitoring (SA, sysdSA).
 
 'Process System daemons' is based on 'sysdaemon 1.60' written by Trans-Euro I.T Ltd
 
